@@ -30,7 +30,7 @@ from sqlalchemy import create_engine
 from sqlalchemy.orm import mapper, sessionmaker as _sessionmaker, relation, backref, \
      object_session as _object_session, class_mapper
 from sqlalchemy.sql import select, text, and_
-from sqlalchemy.exceptions import DBAPIError, OperationalError
+from sqlalchemy.exc import DBAPIError, OperationalError
 from sqlalchemy.pool import NullPool
 import sqlalchemy
 
