@@ -28,20 +28,17 @@ class bdist_dmg(Command):
 	def run(self):
                 self.run_command('py2app')
                 os.system("\
-mkdir -p dist/Anki.app/Contents/Resources/include/python2.6")
+mkdir -p dist/Anki.app/Contents/Resources/include/python2.7")
                 os.system("\
-cp /Library/Frameworks/Python.framework/Versions/2.6/include/\
-python2.6/pyconfig.h dist/Anki.app/Contents/Resources/include/\
-python2.6/pyconfig.h")
+cp /Library/Frameworks/Python.framework/Versions/2.7/include/\
+python2.7/pyconfig.h dist/Anki.app/Contents/Resources/include/\
+python2.7/pyconfig.h")
                 os.system("\
-chmod a+x dist/Anki.app/Contents/Resources/audio/mplayer")
+chmod a+x dist/Anki.app/Contents/Resources/audio/*")
                 if 'debug' in os.environ:
                         return
-                # zlib
-                result = os.spawnvp(os.P_WAIT, 'hdiutil', (
-                        'hdiutil create -ov -format UDZO ' +
-                        '-volname Anki -srcfolder dist ' +
-                        '-o Anki.dmg -imagekey zlib-level=9').split())
+                # make the dmg with the shell script
+                result = os.system('ankiqt/mac/make-dmg.sh')
                 if result is not 0:
                         raise Exception('dmg creation failed %d' % result)
 
@@ -64,7 +61,7 @@ PLIST = dict(
 	CFBundleLocalizations = ['en'],
         )
 OPTIONS = {
-	'argv_emulation': True,
+	'argv_emulation': False,
     'optimize': 0,
         'alias': 'debug' in os.environ and os.environ['debug'] == "2",
 	'plist': PLIST,
